@@ -1,7 +1,7 @@
 /*
  * Java-Gnome Bindings Library
  *
- * Copyright 1998-2003 the Java-Gnome Team, all rights reserved.
+ * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
  *
  * The Java-Gnome bindings library is free software distributed under
  * the terms of the GNU Library General Public License version 2.
@@ -24,22 +24,14 @@ public class Frame extends Bin
 	 * Creates a new frame with no label
 	 */
 	public Frame(){
-		noopInit();
+		super(gtk_frame_new(""));
 	}
 	
 	/**
 	 * Construct a frame using a handle to a native resource.
 	 */
 	public Frame(int handle) {
-	    setHandle(handle);
-	    initializeEventHandlers();
-	}
-
-	protected void noopInit() {
-		if (-1 == getHandle()) {
-			setHandle(gtk_frame_new(""));
-			initializeEventHandlers();
-		}
+	    super(handle);
 	}
 
 	/**
@@ -48,8 +40,7 @@ public class Frame extends Bin
 	 * @param label Text to be displayed in the border of the frame.
 	 */
 	public Frame(String label){
-		setHandle(gtk_frame_new(label));
-		initializeEventHandlers();
+		super(gtk_frame_new(label));
 	}
 
 	/**
