@@ -46,8 +46,8 @@ public class TreeSelection extends GObject {
 	/**
 	 * constructs a new selection using handle from a native function..
 	 */
-	protected TreeSelection(int h) {
-		setHandle(h);
+	protected TreeSelection(int handle) {
+		super(handle);
 		initializeEventHandlers();
 	}
 
@@ -251,9 +251,6 @@ public class TreeSelection extends GObject {
 		fireSelectionEvent(new TreeSelectionEvent(this));
 	}
 
-	/** Are events initialized? */
-	private boolean eventsInitialized = false;
-
 	protected void initializeEventHandlers() {
 		if (!eventsInitialized) {
 			evtMap.initialize(this);
@@ -262,11 +259,15 @@ public class TreeSelection extends GObject {
 	}
 
         public Class getEventListenerClass(String signal) {
-	    return evtMap.getListenerClass(signal);
+	    Class cls = evtMap.getEventListenerClass(signal);
+		if (cls == null) cls = super.getEventListenerClass(signal);
+		return cls;
 	}
 
         public GtkEventType getEventType(String signal) {
-	    return evtMap.getEventType(signal);
+	    GtkEventType et = evtMap.getEventType(signal);
+		if (et == null) et = super.getEventType(signal);
+		return et;
 	}
 
         private static EventMap evtMap = new EventMap();
